Stan Math Library: stan/math/prim/scal/fun/fdim.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fdim.hpp File Reference
`#include <math.h>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <cmath>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
boost::math::tools::promote_args< T1, T2 >::type | stan::math::fdim (T1 a, T2 b)
| The positive difference function (C99). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.